powered by
get_osm download osm data from geofabrik. Instead of other services, this function relies only on direct links. Just that.
get_osm
get_osm(region, type = "shp", file = tempfile(), quiet = FALSE)
Region of interest, see urlgeo
urlgeo
"pbf", "shp" or "osm"
a character string (or vector, see url) with the name where the downloaded file is saved.
If TRUE, suppress status messages (if any), and the progress bar.
Download a file
# NOT RUN { head(urlgeo) get_osm("Sao Tome and Principe") get_osm("Sao Tome and Principe", "pbf") get_osm("Sao Tome and Principe", "osm") # }
Run the code above in your browser using DataLab